@@ -2,10 +2,10 @@ __author__ = "Swas.py"
 __title__ = "vscode"
 __license__ = "MIT"
 __copyright__ = "Copyright 2021 Swas.py"
-__version__ = "1.3.2"
+__version__ = "1.3.3"
 
 from . import window
 from .compiler import build
-from .ext import Extension
+from .extension import Extension
 from .envMethods import env
-from .interfaces import undefined
+from . import _types as ext
